@@ -21,4 +21,6 @@ class NotificationListSerializer(serializers.ModelSerializer):
          request_user = self.context.get('request').user
          if obj.actor == request_user:
              return f"You {obj.action} {str(obj.action_object)}"
+         if hasattr(obj.actor, 'first_name') and obj.actor.first_name:
+             return f"{obj.actor.first_name} {obj.action} {str(obj.action_object)}"
          return f"{obj.actor} {obj.action} {str(obj.action_object)}"
